Work plans (backlogs)
=====================

See at the end: `All pending tasks listed`_.


Python 2 and 3 Compatibility
----------------------------

.. include:: backlog/backlog-six2eight.rst


All pending tasks listed
------------------------

.. todolist::
